import { useState } from "react";

const lists = {
	rodzajFrezowania: ["Czolowe", "Walcowo Czolowe", "Rowkowe"],
	rodzajObrobki: ["Zgrubna", "Wykończeniowa"],
	material: ["Stal węglowa", "Stal nierdzewna", "Żeliwo"],
};
const listsLabels = {
	rodzajFrezowania: "Rodzaj Frezowania",
	rodzajObrobki: "Rodzaj Obróbki",
	material: "Material",
};
import { ChangeEvent } from "react";

interface SelectProps {
	value: string | number;
	onChange: (event: ChangeEvent<HTMLSelectElement>) => void;
	options: string[];
	label: string;
	disabledLabel: string;
}

const Select = ({ value, onChange, options, disabledLabel }: SelectProps) => (
	<select className="select w-full input input-secondary" value={value} onChange={onChange}>
		<option disabled>{disabledLabel}</option>
		{options.map((option, index) => (
			<option key={option} value={index}>
				{option}
			</option>
		))}
	</select>
);

const HomePage = () => {
	const [state, setState] = useState({
		rodzajFrezowania: 0,
		rodzajObrobki: 0,
		material: 0,
		glebokoscSkrawania: Math.floor(Math.random() * 50 + 1),
		szerokoscSkrawania: Math.floor(Math.random() * 30 + 1),
		tolerancja: parseFloat((0.1 + Math.random() * (5 - 0.1)).toFixed(2)),
		chropowatosc: parseFloat((0.1 + Math.random() * (5 - 0.1)).toFixed(2)),
	});

	const handleChange = (key: keyof typeof state) => (e: React.ChangeEvent<HTMLSelectElement>) => {
		const value = Number(e.target.value);
		setState((prev) => ({ ...prev, [key]: value }));
	};

	return (
		<>
			<div className="p-6 bg-white rounded shadow-lg lg:w-[500px] space-y-4 mb-4 lg:absolute lg:right-1/2 lg:translate-x-1/2 lg:translate-y-4">
				<h1 className="text-3xl mb-6 text-center text-gray-700">Wybór parametrów</h1>
				<div className="space-y-4">
					{Object.keys(lists).map((key) => (
						<div className="mb-4">
							<label className="block text-gray-700 text-sm font-bold mb-2">
								{listsLabels[key as keyof typeof listsLabels]}
							</label>
							<Select
								key={key}
								value={state[key as keyof typeof state]}
								onChange={handleChange(key as keyof typeof state)}
								options={lists[key as keyof typeof lists]}
								label={key}
								disabledLabel={`Wybierz ${key}`}
							/>
						</div>
					))}
				</div>

				<label className="flex text-gray-700 text-sm font-bold mb-0">Głębokość Skrawania</label>
				<div className="flex items-center space-x-2">
					<input
						type="range"
						min={1}
						max={50}
						value={state.glebokoscSkrawania}
						className="range flex-grow mr-2 "
						onChange={(e) => {
							setState((prev) => ({ ...prev, glebokoscSkrawania: Number(e.target.value) }));
						}}
					/>
					<div className="flex items-center space-x-2">
						<input
							value={state.glebokoscSkrawania}
							onChange={(e) => {
								setState((prev) => ({ ...prev, glebokoscSkrawania: Number(e.target.value) }));
							}}
							className="input input-secondary w-20"
							type="number"
							min={1}
							max={50}
						/>
						<span>mm</span>
					</div>
				</div>
				<label className="flex text-gray-700 text-sm font-bold mb-0">Szerokość Skrawania</label>
				<div className="flex items-center space-x-2">
					<input
						type="range"
						min={1}
						max={30}
						value={state.szerokoscSkrawania}
						className="range flex-grow mr-2"
						onChange={(e) => {
							setState((prev) => ({ ...prev, szerokoscSkrawania: Number(e.target.value) }));
						}}
					/>
					<div className="flex items-center space-x-2">
						<input
							value={state.szerokoscSkrawania}
							onChange={(e) => {
								setState((prev) => ({ ...prev, szerokoscSkrawania: Number(e.target.value) }));
							}}
							className="input input-secondary w-20"
							type="number"
							min={1}
							max={30}
						/>
						<span>mm</span>
					</div>
				</div>
				<label className="flex text-gray-700 text-sm font-bold mb-0">Tolerancja</label>
				<div className="flex items-center space-x-2">
					<input
						type="range"
						min={0.1}
						max={5}
						value={state.tolerancja}
						className="range flex-grow mr-2"
						onChange={(e) => {
							setState((prev) => ({ ...prev, tolerancja: Number(e.target.value) }));
						}}
						step={0.01}
					/>
					<div className="flex items-center space-x-2">
						<input
							value={state.tolerancja}
							onChange={(e) => {
								setState((prev) => ({ ...prev, tolerancja: Number(e.target.value) }));
							}}
							className="input input-secondary w-20"
							type="number"
							min={0.1}
							max={5}
							step={0.01}
						/>
						<span>mm</span>
					</div>
				</div>
				<label className="flex text-gray-700 text-sm font-bold mb-0">Chropowatość</label>
				<div className="flex items-center space-x-2">
					<input
						type="range"
						min={0.1}
						max={5}
						value={state.chropowatosc}
						className="range flex-grow mr-2"
						onChange={(e) => {
							setState((prev) => ({ ...prev, chropowatosc: Number(e.target.value) }));
						}}
						step={0.01}
					/>
					<div className="flex items-center space-x-2">
						<input
							value={state.chropowatosc}
							onChange={(e) => {
								setState((prev) => ({ ...prev, chropowatosc: Number(e.target.value) }));
							}}
							className="input input-secondary w-20"
							type="number"
							min={0.1}
							max={5}
							step={0.01}
						/>
						<span>mm</span>
					</div>
				</div>

				<button
					className="btn btn-secondary w-full mt-4"
					type="submit"
					onClick={() => {
						console.log(
							state.rodzajFrezowania,
							state.rodzajObrobki,
							state.material,
							state.glebokoscSkrawania,
							state.szerokoscSkrawania,
							state.tolerancja,
							state.chropowatosc,
						);
					}}
				>
					Policz
				</button>
			</div>
			<div className="m-4 p-6 bg-white rounded-lg shadow-md w-fit max-w-xs">
				<h1 className="text-4xl mb-8 text-center text-gray-800 tracking-wider">Wyniki</h1>
				<div className="space-y-2">
					<span className="text-gray-800 block tracking-wide">
						rodzajFrezowania: <span className="text-black font-medium">{state.rodzajFrezowania}</span>
					</span>
					<span className="text-gray-800 block tracking-wide">
						rodzajObrobki: <span className="text-black font-medium">{state.rodzajObrobki}</span>
					</span>
					<span className="text-gray-800 block tracking-wide">
						material: <span className="text-black font-medium">{state.material}</span>
					</span>
					<span className="text-gray-800 block tracking-wide">
						glebokoscSkrawania: <span className="text-black font-medium">{state.glebokoscSkrawania}</span>
					</span>
					<span className="text-gray-800 block tracking-wide">
						szerokoscSkrawania: <span className="text-black font-medium">{state.szerokoscSkrawania}</span>
					</span>
					<span className="text-gray-800 block tracking-wide">
						tolerancja: <span className="text-black font-medium">{state.tolerancja}</span>
					</span>
					<span className="text-gray-800 block tracking-wide">
						chropowatość: <span className="text-black font-medium">{state.chropowatosc}</span>
					</span>
				</div>
			</div>
		</>
	);
};

export default HomePage;
